Welcome to os-vif's documentation!
========================================================

Contents:

.. toctree::
   :maxdepth: 2

   vif_types
   host_info

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

